@@ -6,9 +6,9 @@
 #   Daniel Manrique  <roadmr@ubuntu.com>
 #
 # Checkbox is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
 #
 # Checkbox is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -29,13 +29,14 @@ from io import StringIO, BytesIO
 from tempfile import TemporaryDirectory
 from unittest import TestCase
 
+from plainbox.abc import IJobResult
 from plainbox.impl.exporter import ByteStringStreamTranslator
 from plainbox.impl.exporter import SessionStateExporterBase
 from plainbox.impl.exporter import classproperty
 from plainbox.impl.job import JobDefinition
-from plainbox.impl.result import JobResult, IOLogRecord
+from plainbox.impl.result import MemoryJobResult, IOLogRecord
 from plainbox.impl.session import SessionState
-from plainbox.impl.testing_utils import make_io_log, make_job, make_job_result
+from plainbox.impl.testing_utils import make_job, make_job_result
 
 
 class ClassPropertyTests(TestCase):
@@ -76,12 +77,52 @@ class SessionStateExporterBaseTests(TestCase):
         job_b = make_job('job_b')
         session = SessionState([job_a, job_b])
         session.update_desired_job_list([job_a, job_b])
-        result_a = make_job_result(job_a, 'pass')
-        result_b = make_job_result(job_b, 'fail')
+        result_a = make_job_result(outcome=IJobResult.OUTCOME_PASS)
+        result_b = make_job_result(outcome=IJobResult.OUTCOME_FAIL)
         session.update_job_result(job_a, result_a)
         session.update_job_result(job_b, result_b)
         return session
 
+    def test_option_list_setting_boolean(self):
+        exporter = self.TestSessionStateExporter()
+        exporter._option_list = [
+            SessionStateExporterBase.OPTION_WITH_IO_LOG,
+            SessionStateExporterBase.OPTION_FLATTEN_IO_LOG]
+        self.assertEqual(exporter._option_list, sorted([
+            SessionStateExporterBase.OPTION_WITH_IO_LOG,
+            SessionStateExporterBase.OPTION_FLATTEN_IO_LOG]))
+
+    def test_option_list_setting_boolean_all_at_once(self):
+        # Test every option set, all at once
+        # Just to be paranoid, ensure the options I set are the ones the
+        # exporter actually thinks it has
+        exporter = self.TestSessionStateExporter(
+            self.TestSessionStateExporter.supported_option_list)
+        self.assertEqual(exporter._option_list,
+                sorted(self.TestSessionStateExporter.supported_option_list))
+
+    def test_option_list_init_non_boolean(self):
+        option = SessionStateExporterBase.OPTION_WITH_COMMENTS
+        exporter = self.TestSessionStateExporter(["{}=detailed".format(option)])
+        self.assertEqual(exporter.get_option_value(option),
+                "detailed")
+
+    def test_option_list_non_duplicated_options(self):
+        # Setting the same option twice makes no sense, check it gets squashed
+        # into only one item in the option_list.
+        option = SessionStateExporterBase.OPTION_WITH_COMMENTS
+        exporter = self.TestSessionStateExporter([option, option])
+        self.assertEqual(exporter._option_list, [option])
+
+    def test_option_list_setting_api(self):
+        exporter = self.TestSessionStateExporter(
+                [SessionStateExporterBase.OPTION_WITH_IO_LOG])
+        exporter.set_option_value("with-comments")
+        self.assertEqual(exporter.get_option_value('with-comments'), True)
+        exporter.set_option_value("with-comments", "detailed")
+        self.assertEqual(exporter.get_option_value('with-comments'),
+                "detailed")
+
     def test_defaults(self):
         # Test all defaults, with all options unset
         exporter = self.TestSessionStateExporter()
@@ -115,22 +156,16 @@ class SessionStateExporterBaseTests(TestCase):
         })
         session = SessionState([job_a, job_b])
         session.update_desired_job_list([job_a, job_b])
-        result_a = JobResult({
-            'job': job_a,
-            'outcome': 'pass',
+        result_a = MemoryJobResult({
+            'outcome': IJobResult.OUTCOME_PASS,
             'return_code': 0,
-            'io_log': make_io_log(
-                (IOLogRecord(0, 'stdout', b'testing\n'),),
-                session_dir)
+            'io_log': [(0, 'stdout', b'testing\n')],
         })
-        result_b = JobResult({
-            'job': job_b,
-            'outcome': 'pass',
+        result_b = MemoryJobResult({
+            'outcome': IJobResult.OUTCOME_PASS,
             'return_code': 0,
             'comments': 'foo',
-            'io_log': make_io_log(
-                (IOLogRecord(0, 'stdout', b'ready: yes\n'),),
-                session_dir)
+            'io_log': [(0, 'stdout', b'ready: yes\n')],
         })
         session.update_job_result(job_a, result_a)
         session.update_job_result(job_b, result_b)
@@ -166,6 +201,9 @@ class SessionStateExporterBaseTests(TestCase):
                     'io_log': ['dGVzdGluZwo='],
                     'requires': 'job_b.ready == "yes"',
                     'comments': None,
+                    'via': None,
+                    'hash': '1dbae753f6cb823af370ef9fcb5916'
+                            'eba82185992e81813316fe77332a60f1e0',
                 },
                 'job_b': {
                     'outcome': 'pass',
@@ -173,6 +211,9 @@ class SessionStateExporterBaseTests(TestCase):
                     'command': 'echo ready: yes',
                     'io_log': ['cmVhZHk6IHllcwo='],
                     'comments': 'foo',
+                    'via': None,
+                    'hash': 'a914c7396e29c2a4669055bf38bd7c'
+                            '7f0eae0bc67f8bc2d90ba7d37f83e52132',
                 }
             },
             'attachment_map': {
