@@ -6,9 +6,9 @@
 #   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
 #
 # Checkbox is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
 #
 # Checkbox is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -29,6 +29,7 @@ import io
 
 from pkg_resources import resource_string
 
+from plainbox.abc import IJobResult
 from plainbox.testing_utils import resource_json
 from plainbox.impl.exporter.xml import XMLSessionStateExporter, XMLValidator
 from plainbox.testing_utils.testcases import TestCaseWithParameters
@@ -65,21 +66,56 @@ class XMLSessionStateExporterTests(TestCaseWithParameters):
         self.assertEqual(actual, expected)
 
 
+class XMLExporterStatusMappingTests(TestCaseWithParameters):
+
+    parameter_names = ('checkbox_status',)
+    parameter_values = [(outcome, ) for outcome in IJobResult.ALL_OUTCOME_LIST]
+
+    def test_status_mapping(self):
+        """
+        Ensure that all possible plainbox statuses are mapped to
+        one of the possible ALLOWED_STATUS permitted by checkbox
+        legacy infrastructure.
+        """
+        pb_outcome = self.parameters.checkbox_status
+        self.assertIn(pb_outcome, XMLSessionStateExporter._STATUS_MAP)
+        mapped_status = XMLSessionStateExporter._STATUS_MAP[pb_outcome]
+        self.assertIn(mapped_status,
+                      XMLSessionStateExporter._ALLOWED_STATUS)
+
+
 class XMLExporterTests(TestCase):
 
     def setUp(self):
+        self.prepare_test_exporter()
+
+    def prepare_test_exporter(self, client_name="plainbox",
+                              system_id="",
+                              option_list=None,
+                              timestamp="2012-12-21T12:00:00",
+                              client_version="1.0"):
         data = resource_json(
             "plainbox", "test-data/xml-exporter/example-data.json",
             exact=True)
-        exporter = XMLSessionStateExporter(
-            system_id="",
-            timestamp="2012-12-21T12:00:00",
-            client_version="1.0")
+        self.exporter = XMLSessionStateExporter(
+            client_name=client_name,
+            option_list=option_list,
+            system_id=system_id,
+            timestamp=timestamp,
+            client_version=client_version)
         stream = io.BytesIO()
-        exporter.dump(data, stream)
+        self.exporter.dump(data, stream)
         self.actual_result = stream.getvalue()  # This is bytes
         self.assertIsInstance(self.actual_result, bytes)
 
+    def test_exporter_option(self):
+        """
+        Ensure that the previously-optionless xml exporter can have its
+        single accepted 'client-name' option set properly.
+        """
+        self.prepare_test_exporter(option_list=['client-name=verifythis'])
+        self.assertEqual(self.exporter.get_option_value('client-name'), "verifythis")
+
     def test_perfect_match(self):
         expected_result = resource_string(
             "plainbox", "test-data/xml-exporter/example-data.xml"
@@ -94,3 +130,17 @@ class XMLExporterTests(TestCase):
         self.assertTrue(
             validator.validate_text(
                 self.actual_result))
+
+    def test_client_name_option_takes_precedence(self):
+        # We use trickery to verify the xml final report has the client name
+        # sent in the option string, rather than the constructor parameter.
+        # We pass a bogus client-name in the constructor, then the correct expected
+        # name in the option, and just check as usual.
+        self.prepare_test_exporter(client_name="bogus",
+                                   option_list=['client-name=plainbox'])
+        expected_result = resource_string(
+            "plainbox", "test-data/xml-exporter/example-data.xml"
+        )  # unintuitively, resource_string returns bytes
+        self.assertEqual(self.actual_result, expected_result)
+
+
