@@ -33,6 +33,7 @@ import inspect
 import json
 import logging
 
+from plainbox.i18n import gettext as _
 from plainbox.impl.secure.plugins import PkgResourcesPlugInCollection, PlugIn
 
 
@@ -121,7 +122,8 @@ class ParserPlugIn(IParser, PlugIn):
         """
         ast = self.parse_text_to_ast(text)
         if ast is not None:
-            return json.dumps(ast, indent=4, default=self._to_json)
+            return json.dumps(ast, indent=4, sort_keys=True,
+                              default=self._to_json)
 
     def parse_text_to_ast(self, text):
         """
@@ -135,7 +137,8 @@ class ParserPlugIn(IParser, PlugIn):
         except Exception:
             # TODO: portable parser error would be nice, to know where it
             # fails. This is difficult at this stage.
-            logger.exception("Cannot parse input")
+
+            logger.exception(_("Cannot parse input"))
             return None
 
     def _to_json(self, obj):
