@@ -5,9 +5,9 @@
 #   Sylvain Pineau <sylvain.pineau@canonical.com>
 #
 # Checkbox is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
 #
 # Checkbox is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,7 +21,11 @@
 :mod:`plainbox.impl.secure` -- code for external (trusted) launchers
 ====================================================================
 
-.. warning::
+This package keeps all of the plainbox code that is executed as root. It should
+be carefully reviewed to ensure that we don't introduce security issues that
+could allow unpriviledged uses to exploit plainbox to run arbitrary commands as
+root.
 
-    THIS MODULE DOES NOT HAVE STABLE PUBLIC API
+None of the modues in the secure package may import code that is not coming
+from either the plainbox secure package or from the standard python library.
 """
