@@ -402,6 +402,16 @@ class Provider1(IProvider1, IProviderBackend1):
         if self.base_dir is not None:
             return os.path.join(self.base_dir, 'build', 'bin')
 
+    @property
+    def src_dir(self):
+        """
+        absolute path of the src/ directory
+
+        This value may be None. It depends on location/base_dir set.
+        """
+        if self.base_dir is not None:
+            return os.path.join(self.base_dir, 'src')
+
     @property
     def CHECKBOX_SHARE(self):
         """
@@ -525,7 +535,29 @@ class Provider1(IProvider1, IProviderBackend1):
         """
         return sorted(
             self._get_executables(self.bin_dir) +
-            self._get_executables(self.build_bin_dir))
+            self._get_build_bin_executable_list())
+
+    def _get_build_bin_executable_list(self):
+        """
+        Discover executables that are a part of the build/bin directory.
+
+        The build/bin directory may contain nothing, standalone executables or
+        a whole mess of build artifacts, only some of which are relevant. This
+        method implements the following algorithm:
+
+        * If the src/EXECUTABLES file exists then it must contain the name
+          of each executable relative to the build/bin directory (typically
+          just the name)
+        * Otherwise all executable files from the build/bin directory are
+          returned
+        """
+        if self.src_dir is not None:
+            hint_file = os.path.join(self.src_dir, 'EXECUTABLES')
+            if os.path.isfile(hint_file):
+                with open(hint_file, "rt", encoding='UTF-8') as stream:
+                    return [os.path.join(self.build_bin_dir, line.strip())
+                            for line in stream if line.strip()]
+        return self._get_executables(self.build_bin_dir)
 
     def _get_executables(self, dirname):
         executable_list = []
