@@ -36,6 +36,8 @@ import stat
 import sys
 import tempfile
 
+from plainbox.i18n import gettext as _, ngettext
+
 logger = logging.getLogger("plainbox.session.storage")
 
 
@@ -110,7 +112,7 @@ class SessionStorageRepository:
         :returns:
             list of :class:`SessionStorage` representing discovered sessions
         """
-        logger.debug("Enumerating sessions in %s", self._location)
+        logger.debug(_("Enumerating sessions in %s"), self._location)
         try:
             # Try to enumerate the directory
             item_list = os.listdir(self._location)
@@ -129,7 +131,7 @@ class SessionStorageRepository:
             stat_result = os.lstat(pathname)
             # Consider directories only
             if stat.S_ISDIR(stat_result.st_mode):
-                logger.debug("Found possible session in %r", pathname)
+                logger.debug(_("Found possible session in %r"), pathname)
                 session = SessionStorage(pathname)
                 session_list.append(session)
         # Return the full list
@@ -211,7 +213,7 @@ class SessionStorage:
         return os.path.join(self._location, self._SESSION_FILE)
 
     @classmethod
-    def create(cls, base_dir, legacy_mode=True):
+    def create(cls, base_dir, legacy_mode=False):
         """
         Create a new :class:`SessionStorage` in a random subdirectory
         of the specified base directory. The base directory is also
@@ -242,7 +244,7 @@ class SessionStorage:
             os.makedirs(base_dir)
         location = tempfile.mkdtemp(
             prefix='pbox-', suffix='.session', dir=base_dir)
-        logger.debug("Created new storage in %r", location)
+        logger.debug(_("Created new storage in %r"), location)
         self = cls(location)
         if legacy_mode:
             self._replace_legacy_session(base_dir)
@@ -266,39 +268,40 @@ class SessionStorage:
                 pass
             elif exc.errno == errno.EINVAL:
                 logger.warning(
-                    "%r is not a symlink, repository %r must be corrupted",
+                    _("%r is not a symlink, repository %r must be corrupted"),
                     symlink_pathname, base_dir)
             else:
                 logger.warning(
-                    "Unable to read symlink target from %r: %r",
+                    _("Unable to read symlink target from %r: %r"),
                     symlink_pathname, exc)
         else:
             logger.debug(
-                "Removing storage associated with last session %r",
+                _("Removing storage associated with last session %r"),
                 symlink_target)
             # Remove the old session, note that the symlink may be broken so
             # let's ignore any errors here
             shutil.rmtree(symlink_target, ignore_errors=True)
             # Remove the last-session symlink itself
             logger.debug(
-                "Removing symlink associated with last session: %r",
+                _("Removing symlink associated with last session: %r"),
                 symlink_pathname)
             os.unlink(symlink_pathname)
         finally:
             # Finally put the last-session synlink that points to this storage
-            logger.debug("Linking storage %r to last session", self.location)
+            logger.debug(
+                _("Linking storage %r to last session"), self.location)
             try:
                 os.symlink(self.location, symlink_pathname)
             except OSError as exc:
                 logger.error(
-                    "Cannot link %r as %r: %r",
+                    _("Cannot link %r as %r: %r"),
                     self.location, symlink_pathname, exc)
 
     def remove(self):
         """
         Remove all filesystem entries associated with this instance.
         """
-        logger.debug("Removing session storage from %r", self._location)
+        logger.debug(_("Removing session storage from %r"), self._location)
         shutil.rmtree(self._location)
 
     def load_checkpoint(self):
@@ -362,7 +365,9 @@ class SessionStorage:
         _next_session_pathname = os.path.join(
             self._location, self._SESSION_FILE_NEXT)
         logger.debug(
-            "Forcibly unlinking 'next' file %r:", _next_session_pathname)
+            # TRANSLATORS: unlinking as in deleting a file
+            # Please keep the 'next' string untranslated
+            _("Forcibly unlinking 'next' file %r"), _next_session_pathname)
         os.unlink(_next_session_pathname)
 
     def _load_checkpoint_unix_py32(self):
@@ -370,33 +375,38 @@ class SessionStorage:
         # Open the location directory
         location_fd = os.open(self._location, os.O_DIRECTORY)
         logger.debug(
-            "Opened session directory %r as descriptor %d",
+            _("Opened session directory %r as descriptor %d"),
             self._location, location_fd)
         try:
             # Open the current session file in the location directory
             session_fd = os.open(_session_pathname, os.O_RDONLY)
             logger.debug(
-                "Opened session state file %r as descriptor %d",
+                _("Opened session state file %r as descriptor %d"),
                 _session_pathname, session_fd)
             # Stat the file to know how much to read
             session_stat = os.fstat(session_fd)
             logger.debug(
-                "Stat'ed session state file: %s", session_stat)
+                # TRANSLATORS: stat is a system call name, don't translate it
+                _("Stat'ed session state file: %s"), session_stat)
             try:
                 # Read session data
-                logger.debug(
-                    "Reading %d bytes of session state", session_stat.st_size)
+                logger.debug(ngettext(
+                    "Reading %d byte of session state",
+                    "Reading %d bytes of session state",
+                    session_stat.st_size), session_stat.st_size)
                 data = os.read(session_fd, session_stat.st_size)
-                logger.debug("Read %d bytes of session state", len(data))
+                logger.debug(ngettext(
+                    "Read %d byte of session state",
+                    "Read %d bytes of session state", len(data)), len(data))
                 if len(data) != session_stat.st_size:
-                    raise IOError("partial read?")
+                    raise IOError(_("partial read?"))
             finally:
                 # Close the session file
-                logger.debug("Closed descriptor %d", session_fd)
+                logger.debug(_("Closed descriptor %d"), session_fd)
                 os.close(session_fd)
         finally:
             # Close the location directory
-            logger.debug("Closed descriptor %d", location_fd)
+            logger.debug(_("Closed descriptor %d"), location_fd)
             os.close(location_fd)
         return data
 
@@ -413,7 +423,7 @@ class SessionStorage:
                 # Read session data
                 data = os.read(session_fd, session_stat.st_size)
                 if len(data) != session_stat.st_size:
-                    raise IOError("partial read?")
+                    raise IOError(_("partial read?"))
             finally:
                 # Close the session file
                 os.close(session_fd)
@@ -436,8 +446,10 @@ class SessionStorage:
         # but keep in mind that the rename race is always there.
         if not isinstance(data, bytes):
             raise TypeError("data must be bytes")
-        logger.debug(
-            "Saving %d bytes of data (UNIX, python 3.2 or older)", len(data))
+        logger.debug(ngettext(
+            "Saving %d byte of data (UNIX, python 3.2 or older)",
+            "Saving %d bytes of data (UNIX, python 3.2 or older)",
+            len(data)), len(data))
         # Helper pathnames, needed because we don't have *at functions
         _next_session_pathname = os.path.join(
             self._location, self._SESSION_FILE_NEXT)
@@ -445,7 +457,8 @@ class SessionStorage:
         # Open the location directory, we need to fsync that later
         # XXX: this may fail, maybe we should keep the fd open all the time?
         location_fd = os.open(self._location, os.O_DIRECTORY)
-        logger.debug("Opened %r as descriptor %d", self._location, location_fd)
+        logger.debug(
+            _("Opened %r as descriptor %d"), self._location, location_fd)
         try:
             # Open the "next" file in the location_directory
             #
@@ -468,7 +481,7 @@ class SessionStorage:
                 else:
                     raise
             logger.debug(
-                "Opened next session file %s as descriptor %d",
+                _("Opened next session file %s as descriptor %d"),
                 _next_session_pathname, next_session_fd)
             try:
                 # Write session data to disk
@@ -478,14 +491,17 @@ class SessionStorage:
                 # get a partial write _or_ we run out of disk space, raise an
                 # explicit IOError.
                 num_written = os.write(next_session_fd, data)
-                logger.debug(
+                logger.debug(ngettext(
+                    "Wrote %d byte of data to descriptor %d",
                     "Wrote %d bytes of data to descriptor %d",
-                    num_written, next_session_fd)
+                    num_written), num_written, next_session_fd)
                 if num_written != len(data):
-                    raise IOError("partial write?")
+                    raise IOError(_("partial write?"))
             except:
                 # If anything goes wrong we should unlink the next file.
-                logger.warning("Unlinking %r", _next_session_pathname)
+
+                # TRANSLATORS: unlinking as in deleting a file
+                logger.warning(_("Unlinking %r"), _next_session_pathname)
                 os.unlink(_next_session_pathname)
             else:
                 # If the write was successful we must flush kernel buffers.
@@ -493,44 +509,52 @@ class SessionStorage:
                 # We want to be sure this data is really on disk by now as we
                 # may crash the machine soon after this method exits.
                 logger.debug(
-                    "Calling fsync() on descriptor %d", next_session_fd)
+                    # TRANSLATORS: please don't translate fsync()
+                    _("Calling fsync() on descriptor %d"), next_session_fd)
                 os.fsync(next_session_fd)
             finally:
                 # Close the new session file
-                logger.debug("Closing descriptor %d", next_session_fd)
+                logger.debug(_("Closing descriptor %d"), next_session_fd)
                 os.close(next_session_fd)
             # Rename FILE_NEXT over FILE.
-            logger.debug(
-                "Renaming %r to %r", _next_session_pathname, _session_pathname)
+            logger.debug(_("Renaming %r to %r"),
+                         _next_session_pathname, _session_pathname)
             try:
                 os.rename(_next_session_pathname, _session_pathname)
             except:
                 # Same as above, if we fail we need to unlink the next file
                 # otherwise any other attempts will not be able to open() it
                 # with O_EXCL flag.
-                logger.warning("Unlinking %r", _next_session_pathname)
+
+                # TRANSLATORS: unlinking as in deleting a file
+                logger.warning(_("Unlinking %r"), _next_session_pathname)
                 os.unlink(_next_session_pathname)
             # Flush kernel buffers on the directory.
             #
             # This should ensure the rename operation is really on disk by now.
             # As noted above, this is essential for being able to survive
             # system crash immediately after exiting this method.
-            logger.debug("Calling fsync() on descriptor %d", location_fd)
+
+            # TRANSLATORS: please don't translate fsync()
+            logger.debug(_("Calling fsync() on descriptor %d"), location_fd)
             os.fsync(location_fd)
         finally:
             # Close the location directory
-            logger.debug("Closing descriptor %d", location_fd)
+            logger.debug(_("Closing descriptor %d"), location_fd)
             os.close(location_fd)
 
     def _save_checkpoint_unix_py33(self, data):
         if not isinstance(data, bytes):
             raise TypeError("data must be bytes")
-        logger.debug(
-            "Saving %d bytes of data (UNIX, python 3.2 or older)", len(data))
+        logger.debug(ngettext(
+            "Saving %d byte of data (UNIX, python 3.3 or newer)",
+            "Saving %d bytes of data (UNIX, python 3.3 or newer)",
+            len(data)), len(data))
         # Open the location directory, we need to fsync that later
         # XXX: this may fail, maybe we should keep the fd open all the time?
         location_fd = os.open(self._location, os.O_DIRECTORY)
-        logger.debug("Opened %r as descriptor %d", self._location, location_fd)
+        logger.debug(
+            _("Opened %r as descriptor %d"), self._location, location_fd)
         try:
             # Open the "next" file in the location_directory
             #
@@ -555,7 +579,7 @@ class SessionStorage:
             except FileExistsError:
                 raise LockedStorageError()
             logger.debug(
-                "Opened next session file %s as descriptor %d",
+                _("Opened next session file %s as descriptor %d"),
                 self._SESSION_FILE_NEXT, next_session_fd)
             try:
                 # Write session data to disk
@@ -565,16 +589,19 @@ class SessionStorage:
                 # get a partial write _or_ we run out of disk space, raise an
                 # explicit IOError.
                 num_written = os.write(next_session_fd, data)
-                logger.debug(
-                    "Wrote %d bytes of data to descriptor %d",
+                logger.debug(ngettext(
+                    "Wrote %d byte of data to descriptor %d",
+                    "Wrote %d bytes of data to descriptor %d", num_written),
                     num_written, next_session_fd)
                 if num_written != len(data):
-                    raise IOError("partial write?")
+                    raise IOError(_("partial write?"))
             except:
                 # If anything goes wrong we should unlink the next file. As
                 # with the open() call above we use unlinkat to prevent race
                 # conditions.
-                logger.warning("Unlinking %r", self._SESSION_FILE_NEXT)
+
+                # TRANSLATORS: unlinking as in deleting a file
+                logger.warning(_("Unlinking %r"), self._SESSION_FILE_NEXT)
                 os.unlink(self._SESSION_FILE_NEXT, dir_fd=location_fd)
             else:
                 # If the write was successful we must flush kernel buffers.
@@ -582,18 +609,19 @@ class SessionStorage:
                 # We want to be sure this data is really on disk by now as we
                 # may crash the machine soon after this method exits.
                 logger.debug(
-                    "Calling fsync() on descriptor %d", next_session_fd)
+                    # TRANSLATORS: please don't translate fsync()
+                    _("Calling fsync() on descriptor %d"), next_session_fd)
                 os.fsync(next_session_fd)
             finally:
                 # Close the new session file
-                logger.debug("Closing descriptor %d", next_session_fd)
+                logger.debug(_("Closing descriptor %d"), next_session_fd)
                 os.close(next_session_fd)
             # Rename FILE_NEXT over FILE.
             #
             # Use renameat(2) to ensure that there is no race condition if the
             # location (directory) is being moved
             logger.debug(
-                "Renaming %r to %r",
+                _("Renaming %r to %r"),
                 self._SESSION_FILE_NEXT, self._SESSION_FILE)
             try:
                 os.rename(self._SESSION_FILE_NEXT, self._SESSION_FILE,
@@ -602,16 +630,20 @@ class SessionStorage:
                 # Same as above, if we fail we need to unlink the next file
                 # otherwise any other attempts will not be able to open() it
                 # with O_EXCL flag.
-                logger.warning("Unlinking %r", self._SESSION_FILE_NEXT)
+
+                # TRANSLATORS: unlinking as in deleting a file
+                logger.warning(_("Unlinking %r"), self._SESSION_FILE_NEXT)
                 os.unlink(self._SESSION_FILE_NEXT, dir_fd=location_fd)
             # Flush kernel buffers on the directory.
             #
             # This should ensure the rename operation is really on disk by now.
             # As noted above, this is essential for being able to survive
             # system crash immediately after exiting this method.
-            logger.debug("Calling fsync() on descriptor %d", location_fd)
+
+            # TRANSLATORS: please don't translate fsync()
+            logger.debug(_("Calling fsync() on descriptor %d"), location_fd)
             os.fsync(location_fd)
         finally:
             # Close the location directory
-            logger.debug("Closing descriptor %d", location_fd)
+            logger.debug(_("Closing descriptor %d"), location_fd)
             os.close(location_fd)
