@@ -42,6 +42,19 @@ from plainbox.vendor import mock
 
 class CheckBoxJobValidatorTests(TestCase):
 
+    def test_validate_checks_for_deprecated_name(self):
+        """
+        verify that validate() checks if jobs have a value for the 'id'
+        field.
+        """
+        job = JobDefinition({
+            'name': 'name'
+        })
+        with self.assertRaises(ValidationError) as boom:
+            CheckBoxJobValidator.validate(job, deprecated=True)
+        self.assertEqual(boom.exception.field, JobDefinition.fields.name)
+        self.assertEqual(boom.exception.problem, Problem.deprecated)
+
     def test_validate_checks_for_missing_id(self):
         """
         verify that validate() checks if jobs have a value for the 'id'
@@ -91,7 +104,7 @@ class CheckBoxJobValidatorTests(TestCase):
             'user': 'root'
         })
         with self.assertRaises(ValidationError) as boom:
-            CheckBoxJobValidator.validate(job)
+            CheckBoxJobValidator.validate(job, strict=True)
         self.assertEqual(boom.exception.field, JobDefinition.fields.user)
         self.assertEqual(boom.exception.problem, Problem.useless)
 
@@ -106,7 +119,7 @@ class CheckBoxJobValidatorTests(TestCase):
             'environ': 'VAR_NAME'
         })
         with self.assertRaises(ValidationError) as boom:
-            CheckBoxJobValidator.validate(job)
+            CheckBoxJobValidator.validate(job, strict=True)
         self.assertEqual(boom.exception.field, JobDefinition.fields.environ)
         self.assertEqual(boom.exception.problem, Problem.useless)
 
@@ -137,7 +150,7 @@ class CheckBoxJobValidatorTests(TestCase):
             'command': 'run_some_test'
         })
         with self.assertRaises(ValidationError) as boom:
-            CheckBoxJobValidator.validate(job)
+            CheckBoxJobValidator.validate(job, strict=True)
         self.assertEqual(boom.exception.field, JobDefinition.fields.command)
         self.assertEqual(boom.exception.problem, Problem.useless)
 
@@ -254,11 +267,6 @@ class TestJobDefinition(TestCase):
         self.assertEqual(job.command, None)
         self.assertEqual(job.description, None)
 
-    def test_from_rfc822_record_missing_id(self):
-        record = RFC822Record({'plugin': 'plugin'})
-        with self.assertRaises(ValueError):
-            JobDefinition.from_rfc822_record(record)
-
     def test_str(self):
         job = JobDefinition(self._min_record.data)
         self.assertEqual(str(job), "id")
@@ -488,7 +496,7 @@ class TestJobDefinition(TestCase):
 
     def test_tr_summary(self):
         """
-        Verify that Provider1.tr_description() works as expected
+        Verify that Provider1.tr_summary() works as expected
         """
         job = JobDefinition(self._full_record.data)
         with mock.patch.object(job, "get_normalized_translated_data") as mgntd:
@@ -498,6 +506,14 @@ class TestJobDefinition(TestCase):
         # Ensure tr_summary() returned its return value
         self.assertEqual(retval, mgntd())
 
+    def test_tr_summary__falls_back_to_id(self):
+        """
+        Verify that Provider1.tr_summary() falls back to job.id, if summary is
+        not defined
+        """
+        job = JobDefinition({'id': 'id'})
+        self.assertEqual(job.tr_summary(), 'id')
+
     def test_tr_description(self):
         """
         Verify that Provider1.tr_description() works as expected
