@@ -5,9 +5,9 @@
 #   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
 #
 # Checkbox is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
 #
 # Checkbox is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -159,13 +159,13 @@ class ResourceNodeVisitorTests(TestCase):
 
     def test_smoke(self):
         visitor = ResourceNodeVisitor()
-        self.assertEqual(visitor.names_seen, set())
+        self.assertEqual(visitor.ids_seen, set())
 
-    def test_names_seen(self):
+    def test_ids_seen(self):
         visitor = ResourceNodeVisitor()
         node = ast.parse("package.name == 'fwts' and package.version == '1.2'")
         visitor.visit(node)
-        self.assertEqual(visitor.names_seen, {'package'})
+        self.assertEqual(visitor.ids_seen, {'package'})
 
     def test_name_assignment_disallowed(self):
         visitor = ResourceNodeVisitor()
@@ -239,7 +239,15 @@ class ResourceExpressionTests(TestCase):
         text = "package.name == 'fwts'"
         expr = ResourceExpression(text)
         self.assertEqual(expr.text, text)
-        self.assertEqual(expr.resource_name, "package")
+        self.assertEqual(expr.resource_id, "package")
+        self.assertEqual(expr.implicit_namespace, None)
+
+    def test_namespace_support(self):
+        text = "package.name == 'fwts'"
+        expr = ResourceExpression(text, "2014.com.canonical")
+        self.assertEqual(expr.text, text)
+        self.assertEqual(expr.resource_id, "2014.com.canonical::package")
+        self.assertEqual(expr.implicit_namespace, "2014.com.canonical")
 
     def test_smoke_bad(self):
         self.assertRaises(SyntaxError, ResourceExpression, "barf'")
@@ -252,7 +260,7 @@ class ResourceExpressionTests(TestCase):
         self.assertFalse(ResourceExpression("whatever").evaluate([]))
 
     def test_evaluate_normal(self):
-        # NOTE: the actual expr.resource_name is irrelevant for this test
+        # NOTE: the actual expr.resource_id is irrelevant for this test
         expr = ResourceExpression("obj.a == 2")
         self.assertTrue(
             expr.evaluate([
@@ -265,7 +273,7 @@ class ResourceExpressionTests(TestCase):
                 Resource({'a': 1}), Resource({'a': 3})]))
 
     def test_evaluate_exception(self):
-        # NOTE: the actual expr.resource_name is irrelevant for this test
+        # NOTE: the actual expr.resource_id is irrelevant for this test
         expr = ResourceExpression("obj.a == 2")
         self.assertFalse(expr.evaluate([Resource()]))
 
@@ -287,11 +295,11 @@ class ResourceProgramTests(TestCase):
         self.assertEqual(len(self.prog.expression_list), 2)
         self.assertEqual(self.prog.expression_list[0].text,
                          "package.name == 'fwts'")
-        self.assertEqual(self.prog.expression_list[0].resource_name,
+        self.assertEqual(self.prog.expression_list[0].resource_id,
                          "package")
         self.assertEqual(self.prog.expression_list[1].text,
                          "platform.arch in ('i386', 'amd64')")
-        self.assertEqual(self.prog.expression_list[1].resource_name,
+        self.assertEqual(self.prog.expression_list[1].resource_id,
                          "platform")
 
     def test_required_resources(self):
@@ -340,3 +348,12 @@ class ResourceProgramTests(TestCase):
                 Resource({'arch': 'i386'})]
         }
         self.assertTrue(self.prog.evaluate_or_raise(resource_map))
+
+    def test_namespace_support(self):
+        prog = ResourceProgram(
+            "package.name == 'fwts'\n"
+            "platform.arch in ('i386', 'amd64')",
+            implicit_namespace="2014.com.canonical")
+        self.assertEqual(
+            prog.required_resources,
+            {'2014.com.canonical::package', '2014.com.canonical::platform'})
