@@ -6,9 +6,9 @@
 #   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
 #
 # Checkbox is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
 #
 # Checkbox is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,18 +25,18 @@ plainbox.impl.test_runner
 Test definitions for plainbox.impl.runner module
 """
 
-from mock import Mock, patch
 from tempfile import TemporaryDirectory
 from unittest import TestCase
 import os
 
 from plainbox.impl.job import JobDefinition
-from plainbox.impl.runner import CommandIOLogBuilder
-from plainbox.impl.runner import FallbackCommandOutputPrinter
 from plainbox.impl.runner import CommandOutputWriter
+from plainbox.impl.runner import FallbackCommandOutputPrinter
+from plainbox.impl.runner import IOLogRecordGenerator
 from plainbox.impl.runner import JobRunner
 from plainbox.impl.runner import slugify
 from plainbox.testing_utils.io import TestIO
+from plainbox.vendor.mock import Mock, patch
 
 
 class SlugifyTests(TestCase):
@@ -51,23 +51,24 @@ class SlugifyTests(TestCase):
         self.assertEqual(slugify("1k"), "1k")
 
 
-class CommandIOLogBuilderTests(TestCase):
+class IOLogGeneratorTests(TestCase):
 
     def test_smoke(self):
-        builder = CommandIOLogBuilder()
+        builder = IOLogRecordGenerator()
         # Calling on_begin() resets internal state
         builder.on_begin(None, None)
-        self.assertEqual(builder.io_log, [])
-        # Calling on_line accumulates records
+        builder.on_new_record.connect(
+            lambda record: setattr(self, 'last_record', record))
+        # Calling on_line generates records
         builder.on_line('stdout', b'text\n')
+        self.assertEqual(self.last_record.stream_name, 'stdout')
+        self.assertEqual(self.last_record.data, b'text\n')
         builder.on_line('stdout', b'different text\n')
+        self.assertEqual(self.last_record.stream_name, 'stdout')
+        self.assertEqual(self.last_record.data, b'different text\n')
         builder.on_line('stderr', b'error message\n')
-        self.assertEqual(builder.io_log[0].stream_name, 'stdout')
-        self.assertEqual(builder.io_log[0].data, b'text\n')
-        self.assertEqual(builder.io_log[1].stream_name, 'stdout')
-        self.assertEqual(builder.io_log[1].data, b'different text\n')
-        self.assertEqual(builder.io_log[2].stream_name, 'stderr')
-        self.assertEqual(builder.io_log[2].data, b'error message\n')
+        self.assertEqual(self.last_record.stream_name, 'stderr')
+        self.assertEqual(self.last_record.data, b'error message\n')
 
 
 class FallbackCommandOutputPrinterTests(TestCase):
@@ -116,63 +117,4 @@ class CommandOutputWriterTests(TestCase):
             # After the command is done the logs are left on disk
             writer.on_end(None)
             self.assertFileContentsEqual(stdout, b'text\n')
-            self.assertFileContentsEqual(stderr, b'error\n')
-
-
-class GetScriptEnvTests(TestCase):
-
-    def test_root_env_without_environ_keys(self):
-        with patch.dict('os.environ', {'foo': 'bar'}):
-            job = JobDefinition({
-                'name': 'name',
-                'plugin': 'plugin',
-                'user': 'root',
-            })
-            job._checkbox = Mock()
-            job._checkbox.extra_PYTHONPATH = None
-            job._checkbox.extra_PATH = ""
-            self.assertNotIn(
-                "foo",
-                JobRunner._get_script_env(Mock(), job, only_changes=True))
-
-    def test_root_env_with_environ_keys(self):
-        with patch.dict('os.environ', {'foo': 'bar'}):
-            job = JobDefinition({
-                'name': 'name',
-                'plugin': 'plugin',
-                'user': 'root',
-                'environ': 'foo'
-            })
-            job._checkbox = Mock()
-            job._checkbox.extra_PYTHONPATH = None
-            job._checkbox.extra_PATH = ""
-            self.assertIn(
-                "foo",
-                JobRunner._get_script_env(Mock(), job, only_changes=True))
-
-    def test_user_env_without_environ_keys(self):
-        with patch.dict('os.environ', {'foo': 'bar'}):
-            job = JobDefinition({
-                'name': 'name',
-                'plugin': 'plugin',
-            })
-            job._checkbox = Mock()
-            job._checkbox.extra_PYTHONPATH = None
-            job._checkbox.extra_PATH = ""
-            self.assertIn(
-                "foo",
-                JobRunner._get_script_env(Mock(), job, only_changes=False))
-
-    def test_user_env_with_environ_keys(self):
-        with patch.dict('os.environ', {'foo': 'bar'}):
-            job = JobDefinition({
-                'name': 'name',
-                'plugin': 'plugin',
-                'environ': 'foo'
-            })
-            job._checkbox = Mock()
-            job._checkbox.extra_PYTHONPATH = None
-            job._checkbox.extra_PATH = ""
-            self.assertIn(
-                "foo",
-                JobRunner._get_script_env(Mock(), job, only_changes=False))
+            self.assertFileContentsEqual(stderr, b'error\n')
\ No newline at end of file
